function [metric] = obj_to_min_Q8(X,var_svar_tot,RHO_TOT,STD_TOT)
 
% specify target values (i.e., the values observed in the data) for the
% following second moments: (first row) ratio of std. deviation of
% investment to std. deviation of output, and (second row) ratio of std.
% deviation of trade-balance-to-trend-output to std. deviation of output
% --> these targets follow the procedure in Chapter 7 of the textbook -->
% below (around line 40) "metric" selects which of these values are
% actually targeted (and minimizes the sum of squared deviations)
%
% first input: a vector of candidate values for PHI (=PHIM=PHIX), and PSSI (in
% this order)
% 
% further inputs: (second input) var_svar_tot (contains the variances
% estimated by the SVAR model conditional on tot for tot, tb, y, c, i (in
% this order), (third input) RHO_TOT and (fourth input) STD_TOT, which are
% the estimated serial correlation and variance of residuals from the AR(1)
% tot equation, respectively
% 
% 
% target values (1980-2011)
target = [sqrt(var_svar_tot(5)/var_svar_tot(3))  ;  %sigma_i / sigma_y
        sqrt(var_svar_tot(2)/var_svar_tot(3))]; %sigma_tb / sigma_y

% Take out single parameter values
PHI = X(1);
PHIX = PHI;
PHIM = PHI;
PSSI = X(2);

%Calibration -> compute SS values for given parameters
%Time unit is a year

[sigy0,sigx0,nivv,noutput,ntot,ntby,nc] = mx_function_Q8(PHI,PHI,PSSI,RHO_TOT,STD_TOT);

% model-implied sigma_i / sigma_y --> similar to Table 7.4
model_est = sqrt(sigy0(nivv,nivv)/sigy0(noutput,noutput));
% model-implied sigma_tb / sigma_y --> similar to Table 7.4
model_est(2,1) = sqrt(sigy0(ntby,ntby)/sigy0(noutput,noutput));

% target second moments sigma_i/sigma_y, and sigma_tb/sigma_y
metric = sum((model_est(1)-target(1)).^2)+...
                sum((model_est(2)-target(2)).^2);

end